@@ -102,7 +102,6 @@ with this program; if not, write to the Free Software Foundation, Inc.,
 #include "YQPkgProductDialog.h"
 #include "YQPkgRepoFilterView.h"
 #include "YQPkgRepoList.h"
-#include "YQPkgRpmGroupTagsFilterView.h"
 #include "YQPkgSearchFilterView.h"
 #include "YQPkgServiceFilterView.h"
 #include "YQPkgStatusFilterView.h"
@@ -161,7 +160,6 @@ YQPackageSelector::YQPackageSelector( YWidget *		parent,
     _pkgVersionsView		= 0;
     _repoFilterView		= 0;
     _serviceFilterView		= 0;
-    _rpmGroupTagsFilterView	= 0;
     _searchFilterView		= 0;
     _statusFilterView		= 0;
     _updateProblemFilterView	= 0;
@@ -197,7 +195,6 @@ YQPackageSelector::YQPackageSelector( YWidget *		parent,
 
 	if ( ! searchMode() && ! summaryMode()
 	    && _patternList )			_filters->showPage( _patternList );
-	else if ( _rpmGroupTagsFilterView )	_filters->showPage( _rpmGroupTagsFilterView );
 
 	if ( _statusFilterView )		_filters->showPage( _statusFilterView );
     }
@@ -266,17 +263,6 @@ YQPackageSelector::YQPackageSelector( YWidget *		parent,
 
 }
 
-
-std::string
-YQPackageSelector::iconPath( const std::string &name, int size )
-{
-    // FIXME
-    #define PREFIX "/usr/"
-    return zypp::str::form("%s/share/icons/hicolor/%dx%d/apps/%s.png",
-			   PREFIX, size, size, name.c_str() );
-}
-
-
 void
 YQPackageSelector::basicLayout()
 {
@@ -372,18 +358,6 @@ YQPackageSelector::layoutFilters( QWidget *parent )
 	     _packageKitGroupsFilterView,	SLOT  ( filter()   ) );
 
 
-    //
-    // RPM group tags view
-    //
-
-    _rpmGroupTagsFilterView = new YQPkgRpmGroupTagsFilterView( parent );
-    YUI_CHECK_NEW( _rpmGroupTagsFilterView );
-    _filters->addPage( _( "&RPM Groups" ), _rpmGroupTagsFilterView, "rpm_groups" );
-
-    connect( this,			SIGNAL( loadData() ),
-	     _rpmGroupTagsFilterView,	SLOT  ( filter()   ) );
-
-
     //
     // Languages view
     //
@@ -720,7 +694,6 @@ YQPackageSelector::addMenus()
 	_pkgMenu->addAction(_pkgList->actionSetCurrentUpdate);
 	_pkgMenu->addAction(_pkgList->actionSetCurrentUpdateForce);
 	_pkgMenu->addAction(_pkgList->actionSetCurrentTaboo);
-	_pkgMenu->addAction(_pkgList->actionShowCurrentSolverInfo);
 
 #if ENABLE_SOURCE_RPMS
 	_pkgMenu->addSeparator();
@@ -855,6 +828,9 @@ YQPackageSelector::addMenus()
 					     this, SLOT( pkgVerifySytemModeChanged( bool ) ) );
     _verifySystemModeAction->setCheckable(true);
 
+    // Widget styles can use the text information in the rendering for sections,
+    // or can choose to ignore it and render sections like simple separators.
+    _optionsMenu->addSection( _( "Options for this run only..." ) );
 
     _cleanDepsOnRemoveAction = _optionsMenu->addAction( _( "&Cleanup when deleting packages" ),
 					     this, SLOT( pkgCleanDepsOnRemoveChanged( bool ) ) );
@@ -1001,7 +977,6 @@ YQPackageSelector::makeConnections()
     connectFilter( _repoFilterView,		_pkgList, false );
     connectFilter( _serviceFilterView,	_pkgList, false );
     connectFilter( _packageKitGroupsFilterView,	_pkgList, false );
-    connectFilter( _rpmGroupTagsFilterView,	_pkgList, false );
     connectFilter( _statusFilterView,		_pkgList, false );
     connectFilter( _searchFilterView,		_pkgList, false );
 
@@ -1867,4 +1842,3 @@ void YQPackageSelector::normalCursor()
 }
 
 
-#include "YQPackageSelector.moc"
