@@ -81,7 +81,6 @@ YQPkgObjList::YQPkgObjList( QWidget * parent )
     , actionSetCurrentUpdateForce(0)
     , actionSetCurrentTaboo(0)
     , actionSetCurrentProtected(0)
-    , actionShowCurrentSolverInfo(0)
     , actionSetListInstall(0)
     , actionSetListDontInstall(0)
     , actionSetListKeepInstalled(0)
@@ -122,7 +121,7 @@ YQPkgObjList::YQPkgObjList( QWidget * parent )
     connect( this,      SIGNAL(customContextMenuRequested(const QPoint &)),
 	     this,      SLOT  (slotCustomContextMenu(const QPoint&)));
 
-    setIconSize( QSize( 22, 16 ) );
+    setIconSize( QSize( 16, 16 ) );
 
     setContextMenuPolicy(Qt::CustomContextMenu);
 
@@ -322,23 +321,6 @@ YQPkgObjList::setCurrentStatus( ZyppStatus newStatus, bool doSelectNextItem, boo
 }
 
 
-void
-YQPkgObjList::showSolverInfo()
-{
-    QTreeWidgetItem * listViewItem = currentItem();
-
-    if ( ! listViewItem )
-	return;
-
-    YQPkgObjListItem * item = dynamic_cast<YQPkgObjListItem *> (listViewItem);
-
-    if ( item )
-    {
-	_plugin.createZyppSolverDialog(item->zyppObj()->poolItem());
-    }
-}
-
-
 void
 YQPkgObjList::setAllItemStatus( ZyppStatus newStatus, bool force )
 {
@@ -412,15 +394,18 @@ YQPkgObjList::createActions()
     actionSetCurrentKeepInstalled	= createAction( S_KeepInstalled,	"[<], [-]"	);
     actionSetCurrentDelete		= createAction( S_Del,			"[-]"		);
     actionSetCurrentUpdate		= createAction( S_Update,		"[>], [+]"	);
-    actionSetCurrentUpdateForce		= createAction( _( "Update unconditionally" ),  statusIcon( S_Update, true )  ,statusIcon( S_Update, false ) , "", true ) ;
+
+    actionSetCurrentUpdateForce		= createAction( _( "Update unconditionally" ),
+                                                        statusIcon( S_Update, true ),
+                                                        statusIcon( S_Update, false ) ,
+                                                        "",
+                                                        true ) ;
 
 
 
     actionSetCurrentTaboo		= createAction( S_Taboo,		"[!]"		);
     actionSetCurrentProtected		= createAction( S_Protected, 		"[*]" 		);
 
-    actionShowCurrentSolverInfo		= createAction( _( "Show solver information" ));
-
     actionSetListInstall		= createAction( S_Install,		"", true );
     actionSetListDontInstall		= createAction( S_NoInst,		"", true );
     actionSetListKeepInstalled		= createAction( S_KeepInstalled,	"", true );
@@ -449,7 +434,6 @@ YQPkgObjList::createActions()
     connect( actionSetCurrentUpdateForce,    &QAction::triggered, this, &YQPkgObjList::setCurrentUpdateForce );
     connect( actionSetCurrentTaboo,	     &QAction::triggered, this, &YQPkgObjList::setCurrentTaboo );
     connect( actionSetCurrentProtected,	     &QAction::triggered, this, &YQPkgObjList::setCurrentProtected );
-    connect( actionShowCurrentSolverInfo,    &QAction::triggered, this, &YQPkgObjList::showCurrentSolverInfo );
     connect( actionSetListInstall,	     &QAction::triggered, this, &YQPkgObjList::setListInstall );
     connect( actionSetListDontInstall,	     &QAction::triggered, this, &YQPkgObjList::setListDontInstall );
     connect( actionSetListKeepInstalled,     &QAction::triggered, this, &YQPkgObjList::setListKeepInstalled );
@@ -458,32 +442,6 @@ YQPkgObjList::createActions()
     connect( actionSetListUpdateForce,	     &QAction::triggered, this, &YQPkgObjList::setListUpdateForce );
     connect( actionSetListTaboo,	     &QAction::triggered, this, &YQPkgObjList::setListTaboo );
     connect( actionSetListProtected,	     &QAction::triggered, this, &YQPkgObjList::setListProtected );
-
-    // if the solver info plugin did not success to load (which is, the package
-    // of the plugin is not installed or was not included in the media
-    //
-    // it will show up a popup when called, however, if we are in installation
-    // (that is, target is not / or there is no target at all,
-    // the user will have no chance of installing
-    // the plugin package, therefore we disable the action.
-    //
-    zypp::Target_Ptr target = zypp::getZYpp()->getTarget();
-    if ( ! target || ( target->root() != "/" ) )
-    {
-        // there is no target or the target is mounted out of root
-        // which means install or update
-        // if the plugin did not load
-        if ( ! _plugin.success() )
-        {
-            // grey out the option
-            yuiMilestone() << "Disabling solver info plugin: not available and no target or target is not /" << endl;
-            actionShowCurrentSolverInfo->setVisible(false);
-        }
-        else
-        {
-            yuiMilestone() << "target not available or target or target is not /. Solver info plugin available anyway." << endl;
-        }
-    }
 }
 
 
@@ -539,7 +497,6 @@ YQPkgObjList::createNotInstalledContextMenu()
     _notInstalledContextMenu->addAction( actionSetCurrentInstall	);
     _notInstalledContextMenu->addAction( actionSetCurrentDontInstall	);
     _notInstalledContextMenu->addAction( actionSetCurrentTaboo		);
-    _notInstalledContextMenu->addAction( actionShowCurrentSolverInfo	);
 
     addAllInListSubMenu( _notInstalledContextMenu );
 }
@@ -555,7 +512,6 @@ YQPkgObjList::createInstalledContextMenu()
     _installedContextMenu->addAction( actionSetCurrentDelete		);
     _installedContextMenu->addAction( actionSetCurrentUpdate		);
     _installedContextMenu->addAction( actionSetCurrentUpdateForce	);
-    _installedContextMenu->addAction( actionShowCurrentSolverInfo	);
 
     addAllInListSubMenu( _installedContextMenu );
 }
@@ -606,7 +562,7 @@ void
 YQPkgObjList::updateActions( YQPkgObjListItem * item )
 {
     if ( !item)
-      item = dynamic_cast<YQPkgObjListItem *> ( currentItem() );
+        item = dynamic_cast<YQPkgObjListItem *> ( currentItem() );
 
     if ( item )
     {
@@ -636,7 +592,6 @@ YQPkgObjList::updateActions( YQPkgObjListItem * item )
 	    actionSetCurrentUpdate->setEnabled( false );
 	    actionSetCurrentUpdateForce->setEnabled( false );
 	}
-	actionShowCurrentSolverInfo->setEnabled( true );
     }
     else	// ! item
     {
@@ -650,8 +605,6 @@ YQPkgObjList::updateActions( YQPkgObjListItem * item )
 	actionSetCurrentUpdateForce->setEnabled( false );
 	actionSetCurrentProtected->setEnabled( false );
 
-	actionShowCurrentSolverInfo->setEnabled( false );
-
     }
 }
 
@@ -851,6 +804,7 @@ YQPkgObjList::logExcludeStatistics()
     }
 }
 
+
 void
 YQPkgObjList::applyExcludeRules( QTreeWidgetItem * listViewItem )
 {
@@ -1707,7 +1661,7 @@ void YQPkgObjList::slotCustomContextMenu(const QPoint& pos)
 
         QMenu * contextMenu =
       	    ! item->selectable()->installedEmpty() ?
-              installedContextMenu() : notInstalledContextMenu();
+            installedContextMenu() : notInstalledContextMenu();
 
         if ( contextMenu )
             contextMenu->popup( viewport()->mapToGlobal( pos ) );
@@ -1727,4 +1681,3 @@ QTreeWidgetItem * YQPkgObjList::ExcludedItems::oldParentItem( QTreeWidgetItem *
 
 
 
-#include "YQPkgObjList.moc"
